@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 /* FIXME: Should probably buffer calls to libtiff with TIFFSetWarningHandler
@@ -53,8 +53,8 @@ struct _TiffDocument
 
 typedef struct _TiffDocumentClass TiffDocumentClass;
 
-static void tiff_document_document_thumbnails_iface_init (EvDocumentThumbnailsIface *iface);
-static void tiff_document_document_file_exporter_iface_init (EvFileExporterIface *iface);
+static void tiff_document_document_thumbnails_iface_init (EvDocumentThumbnailsInterface *iface);
+static void tiff_document_document_file_exporter_iface_init (EvFileExporterInterface *iface);
 
 EV_BACKEND_REGISTER_WITH_CODE (TiffDocument, tiff_document,
 			 {
@@ -468,7 +468,7 @@ tiff_document_thumbnails_get_dimensions (EvDocumentThumbnails *document,
 }
 
 static void
-tiff_document_document_thumbnails_iface_init (EvDocumentThumbnailsIface *iface)
+tiff_document_document_thumbnails_iface_init (EvDocumentThumbnailsInterface *iface)
 {
 	iface->get_thumbnail = tiff_document_thumbnails_get_thumbnail;
 	iface->get_dimensions = tiff_document_thumbnails_get_dimensions;
@@ -518,7 +518,7 @@ tiff_document_file_exporter_get_capabilities (EvFileExporter *exporter)
 }
 
 static void
-tiff_document_document_file_exporter_iface_init (EvFileExporterIface *iface)
+tiff_document_document_file_exporter_iface_init (EvFileExporterInterface *iface)
 {
 	iface->begin = tiff_document_file_exporter_begin;
 	iface->do_page = tiff_document_file_exporter_do_page;
