@@ -1,6 +1,7 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
 
    Copyright (C) 2004-2006 Bastien Nocera <hadess@hadess.net>
+   Copyright © 2010 Christian Persch
 
    The Gnome Library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public License as
@@ -14,8 +15,8 @@
 
    You should have received a copy of the GNU Library General Public
    License along with the Gnome Library; see the file COPYING.LIB.  If not,
-   write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301  USA.
 
    Author: Bastien Nocera <hadess@hadess.net>
  */
@@ -36,34 +37,25 @@
 #endif /* HAVE_XTEST */
 #endif /* GDK_WINDOWING_X11 */
 
-#ifdef ENABLE_DBUS
-#include <dbus/dbus.h>
-#include <dbus/dbus-glib.h>
+#include "totem-scrsaver.h"
 
 #define GS_SERVICE   "org.gnome.ScreenSaver"
 #define GS_PATH      "/org/gnome/ScreenSaver"
 #define GS_INTERFACE "org.gnome.ScreenSaver"
-#endif /* ENABLE_DBUS */
-
-#include "totem-scrsaver.h"
 
 #define XSCREENSAVER_MIN_TIMEOUT 60
 
-static GObjectClass *parent_class = NULL;
-static void totem_scrsaver_class_init (TotemScrsaverClass *class);
-static void totem_scrsaver_init       (TotemScrsaver      *parser);
 static void totem_scrsaver_finalize   (GObject *object);
 
-
 struct TotemScrsaverPrivate {
 	/* Whether the screensaver is disabled */
 	gboolean disabled;
 
-#ifdef ENABLE_DBUS
-	DBusGConnection *connection;
-	DBusGProxy *gs_proxy;
+	GDBusProxy *gs_proxy;
+        gboolean have_screensaver_dbus;
+        guint watch_id;
 	guint32 cookie;
-#endif /* ENABLE_DBUS */
+	gboolean old_dbus_api;
 
 	/* To save the screensaver info */
 	int timeout;
@@ -82,92 +74,119 @@ G_DEFINE_TYPE(TotemScrsaver, totem_scrsaver, G_TYPE_OBJECT)
 static gboolean
 screensaver_is_running_dbus (TotemScrsaver *scr)
 {
-#ifdef ENABLE_DBUS
-	if (! scr->priv->connection)
-		return FALSE;
+        return scr->priv->have_screensaver_dbus;
+}
 
-	if (! scr->priv->gs_proxy)
-		return FALSE;
+static void
+on_inhibit_cb (GObject      *source_object,
+	       GAsyncResult *res,
+	       gpointer      user_data)
+{
+	GDBusProxy    *proxy = G_DBUS_PROXY (source_object);
+	TotemScrsaver *scr = TOTEM_SCRSAVER (user_data);
+	GVariant      *value;
+	GError        *error = NULL;
 
-	return TRUE;
-#else
-	return FALSE;
-#endif /* ENABLE_DBUS */
+	value = g_dbus_proxy_call_finish (proxy, res, &error);
+	if (!value) {
+		if (!scr->priv->old_dbus_api &&
+		    g_error_matches (error, G_DBUS_ERROR, G_DBUS_ERROR_UNKNOWN_METHOD)) {
+			/* try the old API */
+			scr->priv->old_dbus_api = TRUE;
+			g_dbus_proxy_call (proxy,
+					   "InhibitActivation",
+					   g_variant_new ("(s)",
+							  _("Running in presentation mode")),
+					   G_DBUS_CALL_FLAGS_NO_AUTO_START,
+					   -1,
+					   NULL,
+					   on_inhibit_cb,
+					   scr);
+		} else {
+			g_warning ("Problem inhibiting the screensaver: %s", error->message);
+		}
+		g_error_free (error);
+
+		return;
+	}
+
+	/* save the cookie */
+	if (g_variant_is_of_type (value, G_VARIANT_TYPE ("(u)")))
+		g_variant_get (value, "(u)", &scr->priv->cookie);
+	else
+		scr->priv->cookie = 0;
+	g_variant_unref (value);
+}
+
+static void
+on_uninhibit_cb (GObject      *source_object,
+		 GAsyncResult *res,
+		 gpointer      user_data)
+{
+	GDBusProxy    *proxy = G_DBUS_PROXY (source_object);
+	TotemScrsaver *scr = TOTEM_SCRSAVER (user_data);
+	GVariant      *value;
+	GError        *error = NULL;
+
+	value = g_dbus_proxy_call_finish (proxy, res, &error);
+	if (!value) {
+		if (!scr->priv->old_dbus_api &&
+		    g_error_matches (error, G_DBUS_ERROR, G_DBUS_ERROR_UNKNOWN_METHOD)) {
+			/* try the old API */
+			scr->priv->old_dbus_api = TRUE;
+			g_dbus_proxy_call (proxy,
+					   "AllowActivation",
+					   g_variant_new ("()"),
+					   G_DBUS_CALL_FLAGS_NO_AUTO_START,
+					   -1,
+					   NULL,
+					   on_uninhibit_cb,
+					   scr);
+		} else {
+			g_warning ("Problem uninhibiting the screensaver: %s", error->message);
+		}
+		g_error_free (error);
+
+		return;
+	}
+
+	/* clear the cookie */
+	scr->priv->cookie = 0;
+	g_variant_unref (value);
 }
 
 static void
 screensaver_inhibit_dbus (TotemScrsaver *scr,
 			  gboolean	 inhibit)
 {
-#ifdef ENABLE_DBUS
-	GError *error;
-	gboolean res;
+        TotemScrsaverPrivate *priv = scr->priv;
 
-	g_return_if_fail (scr != NULL);
-	g_return_if_fail (scr->priv->connection != NULL);
-	g_return_if_fail (scr->priv->gs_proxy != NULL);
+        if (!priv->have_screensaver_dbus)
+                return;
+
+	scr->priv->old_dbus_api = FALSE;
 
-	error = NULL;
 	if (inhibit) {
-		char   *application;
-		char   *reason;
-		guint32 cookie;
-
-		application = g_strdup ("Evince");
-		reason = g_strdup (_("Running in presentation mode"));
-
-		res = dbus_g_proxy_call (scr->priv->gs_proxy,
-					 "Inhibit",
-					 &error,
-					 G_TYPE_STRING, application,
-					 G_TYPE_STRING, reason,
-					 G_TYPE_INVALID,
-					 G_TYPE_UINT, &cookie,
-					 G_TYPE_INVALID);
-
-		if (res) {
-			/* save the cookie */
-			scr->priv->cookie = cookie;
-		} else {
-			/* try the old API */
-			res = dbus_g_proxy_call (scr->priv->gs_proxy,
-						 "InhibitActivation",
-						 &error,
-						 G_TYPE_STRING, reason,
-						 G_TYPE_INVALID,
-						 G_TYPE_INVALID);
-		}
-
-		g_free (reason);
-		g_free (application);
-
+		g_dbus_proxy_call (priv->gs_proxy,
+				   "Inhibit",
+				   g_variant_new ("(ss)",
+						  "Evince",
+						  _("Running in presentation mode")),
+				   G_DBUS_CALL_FLAGS_NO_AUTO_START,
+				   -1,
+				   NULL,
+				   on_inhibit_cb,
+				   scr);
 	} else {
-		res = dbus_g_proxy_call (scr->priv->gs_proxy,
-					 "UnInhibit",
-					 &error,
-					 G_TYPE_UINT, scr->priv->cookie,
-					 G_TYPE_INVALID,
-					 G_TYPE_INVALID);
-		if (res) {
-			/* clear the cookie */
-			scr->priv->cookie = 0;
-		} else {
-			/* try the old API */
-			res = dbus_g_proxy_call (scr->priv->gs_proxy,
-						 "AllowActivation",
-						 &error,
-						 G_TYPE_INVALID,
-						 G_TYPE_INVALID);
-		}
+                g_dbus_proxy_call (priv->gs_proxy,
+				   "UnInhibit",
+				   g_variant_new ("(u)", priv->cookie),
+				   G_DBUS_CALL_FLAGS_NO_AUTO_START,
+				   -1,
+				   NULL,
+				   on_uninhibit_cb,
+				   scr);
 	}
-
-	if (! res) {
-		if (error) {
-			g_warning ("Problem inhibiting the screensaver: %s", error->message);
-			g_error_free (error);
-		}
-	}
-#endif /* ENABLE_DBUS */
 }
 
 static void
@@ -182,62 +201,66 @@ screensaver_disable_dbus (TotemScrsaver *scr)
 	screensaver_inhibit_dbus (scr, TRUE);
 }
 
-#ifdef ENABLE_DBUS
 static void
-gs_proxy_destroy_cb (GObject *proxy,
-		     TotemScrsaver *scr)
+screensaver_dbus_appeared_cb (GDBusConnection *connection,
+			      const gchar     *name,
+			      const gchar     *name_owner,
+			      GDBusProxy      *proxy,
+			      gpointer         user_data)
 {
-	g_warning ("Detected that GNOME screensaver has left the bus");
+        TotemScrsaver *scr = TOTEM_SCRSAVER (user_data);
+        TotemScrsaverPrivate *priv = scr->priv;
 
-	/* just invalidate for now */
-	scr->priv->gs_proxy = NULL;
+	priv->gs_proxy = g_object_ref (proxy);
+
+        priv->have_screensaver_dbus = TRUE;
 }
-#endif
 
-#ifdef ENABLE_DBUS
 static void
-screensaver_init_dbus (TotemScrsaver *scr, DBusGConnection *connection)
+screensaver_dbus_disappeared_cb (GDBusConnection *connection,
+				 const gchar     *name,
+				 gpointer         user_data)
 {
-	GError *error = NULL;
-
-	if (!connection)
-		scr->priv->connection = dbus_g_bus_get (DBUS_BUS_SESSION, &error);
-	else
-		scr->priv->connection = connection;
-
-	if (! scr->priv->connection) {
-		if (error) {
-			g_warning ("Failed to connect to the session bus: %s", error->message);
-			g_error_free (error);
-		}
-		return;
-	}
-
-	scr->priv->gs_proxy = dbus_g_proxy_new_for_name_owner (scr->priv->connection,
-							       GS_SERVICE,
-							       GS_PATH,
-							       GS_INTERFACE,
-							       NULL);
-	if (scr->priv->gs_proxy != NULL) {
-		g_signal_connect_object (scr->priv->gs_proxy,
-					 "destroy",
-					 G_CALLBACK (gs_proxy_destroy_cb),
-					 scr,
-					 0);
+        TotemScrsaver *scr = TOTEM_SCRSAVER (user_data);
+        TotemScrsaverPrivate *priv = scr->priv;
 
+	if (priv->gs_proxy) {
+		g_object_unref (priv->gs_proxy);
+		priv->gs_proxy = NULL;
 	}
 
+        priv->have_screensaver_dbus = FALSE;
+}
+
+static void
+screensaver_init_dbus (TotemScrsaver *scr)
+{
+	TotemScrsaverPrivate *priv = scr->priv;
+
+        priv->watch_id = g_bus_watch_proxy (G_BUS_TYPE_SESSION,
+					    GS_SERVICE,
+					    G_BUS_NAME_WATCHER_FLAGS_NONE,
+					    GS_PATH,
+					    GS_INTERFACE,
+					    G_TYPE_DBUS_PROXY,
+					    G_DBUS_PROXY_FLAGS_DO_NOT_LOAD_PROPERTIES |
+					    G_DBUS_PROXY_FLAGS_DO_NOT_CONNECT_SIGNALS,
+					    screensaver_dbus_appeared_cb,
+					    screensaver_dbus_disappeared_cb,
+					    scr, NULL);
 }
-#endif /* ENABLE_DBUS */
 
 static void
 screensaver_finalize_dbus (TotemScrsaver *scr)
 {
-#ifdef ENABLE_DBUS
+        TotemScrsaverPrivate *priv = scr->priv;
+
 	if (scr->priv->gs_proxy) {
 		g_object_unref (scr->priv->gs_proxy);
 	}
-#endif /* ENABLE_DBUS */
+
+	if (priv->watch_id > 0)
+		g_bus_unwatch_proxy (priv->watch_id);
 }
 
 #ifdef GDK_WINDOWING_X11
@@ -299,13 +322,12 @@ screensaver_disable_x11 (TotemScrsaver *scr)
 				&scr->priv->allow_exposures);
 		XUnlockDisplay (GDK_DISPLAY());
 
-		if (scr->priv->timeout != 0)
-		{
+		if (scr->priv->timeout != 0) {
 			g_timeout_add_seconds (scr->priv->timeout / 2,
 					       (GSourceFunc) fake_event, scr);
 		} else {
 			g_timeout_add_seconds (XSCREENSAVER_MIN_TIMEOUT / 2,
-					(GSourceFunc) fake_event, scr);
+					       (GSourceFunc) fake_event, scr);
 		}
 
 		return;
@@ -361,50 +383,40 @@ totem_scrsaver_class_init (TotemScrsaverClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-	parent_class = g_type_class_peek_parent (klass);
+	g_type_class_add_private (klass, sizeof (TotemScrsaverPrivate));
 
 	object_class->finalize = totem_scrsaver_finalize;
 }
 
-#ifdef ENABLE_DBUS
+/**
+ * totem_scrsaver_new:
+ *
+ * Creates a #TotemScrsaver object.
+ * If the GNOME screen saver is running, it uses its DBUS interface to
+ * inhibit the screensaver; otherwise it falls back to using the X
+ * screensaver functionality for this.
+ *
+ * Returns: a newly created #TotemScrsaver
+ */
 TotemScrsaver *
-totem_scrsaver_new	(DBusGConnection *connection)
+totem_scrsaver_new (void)
 {
-	TotemScrsaver * scr;
-	scr = TOTEM_SCRSAVER (g_object_new (TOTEM_TYPE_SCRSAVER, NULL));
-
-	screensaver_init_dbus (scr, connection);
-#ifdef GDK_WINDOWING_X11
-	screensaver_init_x11 (scr);
-#else
-#warning Unimplemented
-#endif
-	
-	return scr;
+	return TOTEM_SCRSAVER (g_object_new (TOTEM_TYPE_SCRSAVER, NULL));
 }
-#else
-TotemScrsaver *
-totem_scrsaver_new()
-{
-	TotemScrsaver * scr;
-	scr = TOTEM_SCRSAVER (g_object_new (TOTEM_TYPE_SCRSAVER, NULL));
-
-#ifdef GDK_WINDOWING_X11
-	screensaver_init_x11 (scr);
-#else
-#warning Unimplemented
-#endif
-	
-	return scr;
-}
-#endif
 
 static void
 totem_scrsaver_init (TotemScrsaver *scr)
 {
-	scr->priv = g_new0 (TotemScrsaverPrivate, 1);
+	scr->priv = G_TYPE_INSTANCE_GET_PRIVATE (scr,
+						 TOTEM_TYPE_SCRSAVER,
+						 TotemScrsaverPrivate);
 
-	
+	screensaver_init_dbus (scr);
+#ifdef GDK_WINDOWING_X11
+	screensaver_init_x11 (scr);
+#else
+#warning Unimplemented
+#endif
 }
 
 void
@@ -449,6 +461,20 @@ totem_scrsaver_enable (TotemScrsaver *scr)
 #endif
 }
 
+void
+totem_scrsaver_set_state (TotemScrsaver *scr, gboolean enable)
+{
+	g_return_if_fail (TOTEM_SCRSAVER (scr));
+
+	if (scr->priv->disabled == !enable)
+		return;
+
+	if (enable == FALSE)
+		totem_scrsaver_disable (scr);
+	else
+		totem_scrsaver_enable (scr);
+}
+
 static void
 totem_scrsaver_finalize (GObject *object)
 {
@@ -462,10 +488,5 @@ totem_scrsaver_finalize (GObject *object)
 	{}
 #endif
 
-	g_free (scr->priv);
-
-	if (G_OBJECT_CLASS (parent_class)->finalize != NULL) {
-		(* G_OBJECT_CLASS (parent_class)->finalize) (object);
-	}
+        G_OBJECT_CLASS (totem_scrsaver_parent_class)->finalize (object);
 }
-
