@@ -15,16 +15,16 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #include <config.h>
 #include "ev-document-forms.h"
 
-EV_DEFINE_INTERFACE (EvDocumentForms, ev_document_forms, 0)
+G_DEFINE_INTERFACE (EvDocumentForms, ev_document_forms, 0)
 
 static void
-ev_document_forms_class_init (EvDocumentFormsIface *klass)
+ev_document_forms_default_init (EvDocumentFormsInterface *klass)
 {
 }
 
@@ -32,7 +32,7 @@ GList *
 ev_document_forms_get_form_fields (EvDocumentForms *document_forms,
 				   EvPage          *page)
 {
-	EvDocumentFormsIface *iface = EV_DOCUMENT_FORMS_GET_IFACE (document_forms);
+	EvDocumentFormsInterface *iface = EV_DOCUMENT_FORMS_GET_IFACE (document_forms);
 
 	return iface->get_form_fields (document_forms, page);
 }
@@ -41,7 +41,7 @@ gchar *
 ev_document_forms_form_field_text_get_text (EvDocumentForms *document_forms, 
 					    EvFormField     *field)
 {
-	EvDocumentFormsIface *iface = EV_DOCUMENT_FORMS_GET_IFACE (document_forms);
+	EvDocumentFormsInterface *iface = EV_DOCUMENT_FORMS_GET_IFACE (document_forms);
 
 	return iface->form_field_text_get_text (document_forms, field);
 }
@@ -51,7 +51,7 @@ ev_document_forms_form_field_text_set_text (EvDocumentForms *document_forms,
 					    EvFormField     *field, 
 					    const gchar     *text)
 {
-	EvDocumentFormsIface *iface = EV_DOCUMENT_FORMS_GET_IFACE (document_forms);
+	EvDocumentFormsInterface *iface = EV_DOCUMENT_FORMS_GET_IFACE (document_forms);
 
 	iface->form_field_text_set_text (document_forms, field, text);
 }
@@ -60,7 +60,7 @@ gboolean
 ev_document_forms_form_field_button_get_state (EvDocumentForms   *document_forms,
 					       EvFormField       *field)
 {
-	EvDocumentFormsIface *iface = EV_DOCUMENT_FORMS_GET_IFACE (document_forms);
+	EvDocumentFormsInterface *iface = EV_DOCUMENT_FORMS_GET_IFACE (document_forms);
 
 	return iface->form_field_button_get_state (document_forms, field);
 }
@@ -70,7 +70,7 @@ ev_document_forms_form_field_button_set_state (EvDocumentForms   *document_forms
 					       EvFormField       *field, 
 					       gboolean           state)
 {
-	EvDocumentFormsIface *iface = EV_DOCUMENT_FORMS_GET_IFACE (document_forms);
+	EvDocumentFormsInterface *iface = EV_DOCUMENT_FORMS_GET_IFACE (document_forms);
 
 	iface->form_field_button_set_state (document_forms, field, state);
 }
@@ -80,7 +80,7 @@ ev_document_forms_form_field_choice_get_item (EvDocumentForms   *document_forms,
 					      EvFormField       *field, 
 					      gint               index)
 {
-	EvDocumentFormsIface *iface = EV_DOCUMENT_FORMS_GET_IFACE (document_forms);
+	EvDocumentFormsInterface *iface = EV_DOCUMENT_FORMS_GET_IFACE (document_forms);
 
 	return iface->form_field_choice_get_item (document_forms, field, index);
 }
@@ -89,7 +89,7 @@ gint
 ev_document_forms_form_field_choice_get_n_items (EvDocumentForms   *document_forms, 
 						 EvFormField       *field)
 {
-	EvDocumentFormsIface *iface = EV_DOCUMENT_FORMS_GET_IFACE (document_forms);
+	EvDocumentFormsInterface *iface = EV_DOCUMENT_FORMS_GET_IFACE (document_forms);
 
 	return iface->form_field_choice_get_n_items (document_forms, field);
 }
@@ -99,7 +99,7 @@ ev_document_forms_form_field_choice_is_item_selected (EvDocumentForms   *documen
 						      EvFormField       *field, 
 						      gint               index)
 {
-	EvDocumentFormsIface *iface = EV_DOCUMENT_FORMS_GET_IFACE (document_forms);
+	EvDocumentFormsInterface *iface = EV_DOCUMENT_FORMS_GET_IFACE (document_forms);
 
 	return iface->form_field_choice_is_item_selected (document_forms, field, index);
 }
@@ -109,7 +109,7 @@ ev_document_forms_form_field_choice_select_item (EvDocumentForms   *document_for
 						 EvFormField       *field, 
 						 gint               index)
 {
-	EvDocumentFormsIface *iface = EV_DOCUMENT_FORMS_GET_IFACE (document_forms);
+	EvDocumentFormsInterface *iface = EV_DOCUMENT_FORMS_GET_IFACE (document_forms);
 
 	iface->form_field_choice_select_item (document_forms, field, index);
 }
@@ -119,7 +119,7 @@ ev_document_forms_form_field_choice_toggle_item (EvDocumentForms   *document_for
 						 EvFormField       *field, 
 						 gint               index)
 {
-	EvDocumentFormsIface *iface = EV_DOCUMENT_FORMS_GET_IFACE (document_forms);
+	EvDocumentFormsInterface *iface = EV_DOCUMENT_FORMS_GET_IFACE (document_forms);
 
 	iface->form_field_choice_toggle_item (document_forms, field, index);
 }
@@ -128,7 +128,7 @@ void
 ev_document_forms_form_field_choice_unselect_all (EvDocumentForms   *document_forms, 
 						  EvFormField       *field)
 {
-	EvDocumentFormsIface *iface = EV_DOCUMENT_FORMS_GET_IFACE (document_forms);
+	EvDocumentFormsInterface *iface = EV_DOCUMENT_FORMS_GET_IFACE (document_forms);
 
 	iface->form_field_choice_unselect_all (document_forms, field);
 }
@@ -138,7 +138,7 @@ ev_document_forms_form_field_choice_set_text (EvDocumentForms   *document_forms,
 					      EvFormField       *field,
 					      const gchar       *text)
 {
-	EvDocumentFormsIface *iface = EV_DOCUMENT_FORMS_GET_IFACE (document_forms);
+	EvDocumentFormsInterface *iface = EV_DOCUMENT_FORMS_GET_IFACE (document_forms);
 
 	iface->form_field_choice_set_text (document_forms, field, text);
 }
@@ -147,7 +147,7 @@ gchar *
 ev_document_forms_form_field_choice_get_text (EvDocumentForms   *document_forms,
 					      EvFormField       *field)
 {
-	EvDocumentFormsIface *iface = EV_DOCUMENT_FORMS_GET_IFACE (document_forms);
+	EvDocumentFormsInterface *iface = EV_DOCUMENT_FORMS_GET_IFACE (document_forms);
 
 	return iface->form_field_choice_get_text (document_forms, field);
 }
