@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 
@@ -241,6 +241,7 @@ void
 ev_password_view_ask_password (EvPasswordView *password_view)
 {
 	GtkDialog *dialog;
+	GtkWidget *content_area, *action_area;
 	GtkWidget *entry_container;
 	GtkWidget *hbox, *main_vbox, *vbox, *icon;
 	GtkWidget *table;
@@ -250,13 +251,15 @@ ev_password_view_ask_password (EvPasswordView *password_view)
 	gtk_widget_set_sensitive (GTK_WIDGET (password_view), FALSE);
 	
 	dialog = GTK_DIALOG (gtk_dialog_new ());
-	
+	content_area = gtk_dialog_get_content_area (dialog);
+	action_area = gtk_dialog_get_action_area (dialog);
+
 	/* Set the dialog up with HIG properties */
 	gtk_dialog_set_has_separator (dialog, FALSE);
 	gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
-	gtk_box_set_spacing (GTK_BOX (dialog->vbox), 2); /* 2 * 5 + 2 = 12 */
-	gtk_container_set_border_width (GTK_CONTAINER (dialog->action_area), 5);
-	gtk_box_set_spacing (GTK_BOX (dialog->action_area), 6);
+	gtk_box_set_spacing (GTK_BOX (content_area), 2); /* 2 * 5 + 2 = 12 */
+	gtk_container_set_border_width (GTK_CONTAINER (action_area), 5);
+	gtk_box_set_spacing (GTK_BOX (action_area), 6);
 
 	gtk_window_set_title (GTK_WINDOW (dialog), _("Enter password"));
 	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
@@ -279,7 +282,7 @@ ev_password_view_ask_password (EvPasswordView *password_view)
 	/* Build contents */
 	hbox = gtk_hbox_new (FALSE, 12);
 	gtk_container_set_border_width (GTK_CONTAINER (hbox), 5);
-	gtk_box_pack_start (GTK_BOX (dialog->vbox), hbox, TRUE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (content_area), hbox, TRUE, TRUE, 0);
 	gtk_widget_show (hbox);
 
 	icon = gtk_image_new_from_stock (GTK_STOCK_DIALOG_AUTHENTICATION,
@@ -374,7 +377,7 @@ ev_password_view_ask_password (EvPasswordView *password_view)
 		gtk_widget_show (choice);
 
 		group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (choice));
-		choice = gtk_radio_button_new_with_mnemonic (group, _("Remember password until you _logout"));
+		choice = gtk_radio_button_new_with_mnemonic (group, _("Remember password until you _log out"));
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (choice),
 					      password_view->priv->password_save == G_PASSWORD_SAVE_FOR_SESSION);
 		g_object_set_data (G_OBJECT (choice), "password-save",
@@ -398,7 +401,7 @@ ev_password_view_ask_password (EvPasswordView *password_view)
 		gtk_widget_show (choice);
 	}
 
-	g_signal_connect (G_OBJECT (dialog), "response",
+	g_signal_connect (dialog, "response",
 			  G_CALLBACK (ev_password_dialog_got_response),
 			  password_view);
 	
